# batgrl
<sup>**b**ad**a**ss **t**erminal **gr**aphics **l**ibrary</sup>

Create games:

![Tetris](https://raw.githubusercontent.com/salt-die/batgrl/main/preview_images/tetris.png)

Simulations:

![Cloth](https://raw.githubusercontent.com/salt-die/batgrl/main/preview_images/cloth.png)

Or entire feature-filled applications:

![Windows](https://raw.githubusercontent.com/salt-die/batgrl/main/preview_images/windows.png)

See it in action: [Video Preview](https://youtu.be/LLI6ANQ6MH4).

[Read the docs](https://salt-die.github.io/batgrl/index.html)
